@@ -1,12 +1,5 @@
-"""
-Contains a class PyYtData having implementation of youtube data v3 client.
-"""
-
-import os
-import webbrowser
-import json
-
-from apiclient.discovery import build
+"""Contains a class PyYtData having implementation of youtube data v3 client"""
+from typing import List
 
 from .util import VidInfo
 
@@ -17,17 +10,16 @@ class PyYtData:
     having attributes as the query parameter for API.
     """
 
-    def __init__(self, keyword, maxlen, order="relevance", type="video"):
+    def __init__(self, keyword: str, maxlen: int, type: str = "video") -> None:
         self.keyword = keyword
-        self.order = order
         self.maxlen = maxlen
         self.type = type
 
-    def get_videoinfo(self):
+    def get_videoinfo(self) -> List:
         """Returns a list with has objects of VidInfo class"""
         rslt = []
 
         for i in range(self.maxlen):
-            vid = VidInfo(self.keyword, self.maxlen, i, self.order, self.type)
+            vid = VidInfo(self.type, self.keyword, self.maxlen, i)
             rslt.append(vid)
         return rslt
